---
myst:
  html_meta:
    "description": "A RESTful API for Plone."
    "property=og:description": "A RESTful API for Plone."
    "property=og:title": "REST API"
    "keywords": "Plone, plone.restapi, REST, API"
---

% plone.restapi documentation master file, created by
% sphinx-quickstart on Mon Apr 28 13:04:12 2014.
% You can adapt this file completely to your liking, but it should at least
% contain the root `toctree` directive.

# REST API

A RESTful API for Plone.

```{toctree}
:caption: Table of Contents
:maxdepth: 2

introduction
usage/index
endpoints/index
upgrade-guide
contributing/index
```

```{eval-rst}
.. include:: ../../README.rst
```


## Appendix and Glossary

```{toctree}
http-status-codes
glossary
```


## Index

- {ref}`genindex`
